@@ -235,7 +235,7 @@ def _plot_histogram(df, columns=None, **kwargs):
         for i, col in enumerate(columns):
             fig.add_trace(
                 go.Histogram(
-                    x=df[col] * 100,
+                    x=df[col],
                     nbinsx=kwargs.get("nbinsx", 50),
                     name=col,
                     opacity=0.75,
@@ -249,7 +249,7 @@ def _plot_histogram(df, columns=None, **kwargs):
             r, c = divmod(i, ncols)
             fig.add_trace(
                 go.Histogram(
-                    x=df[col] * 100,
+                    x=df[col],
                     nbinsx=kwargs.get("nbinsx", 50),
                     name=col,
                     opacity=0.75,
