@@ -16,10 +16,10 @@
 # limitations under the License.
 #
 
-from .optioninputs import OptionInputs
+from .optioninputs import OptionInputs, OptionType, ExerciseStyle, BarrierType
 from .blackscholes import BlackScholesOptionPricing
-from .montecarlo import BarrierType, MonteCarloOptionPricing
-from .binomial import OptionType, ExerciseStyle, BinomialOptionPricing
+from .montecarlo import MonteCarloOptionPricing
+from .binomial import BinomialOptionPricing
 
 
 __all__ = [
